import { LobbyClient } from "boardgame.io/client";
import { BASE_URL, LOBBY_SERVER } from "../consts.ts";
import { AcrossTheHex, SetupData } from "../game.ts";
import classes from "./MatchMaker.module.css";
import { createSignal } from "solid-js";


export default function MatchMaker() {
    const client = new LobbyClient({
        server: LOBBY_SERVER
    });

    const [gridSize, setGridSize] = createSignal(4);
    const [initialResources, setInitialResources] = createSignal(2);

    return <div class={classes.matchmaker}>
        <div class={classes.setting}>
            Grid size:
            <input type="number" value={gridSize()} min={1} max={20} onChange={(event) => setGridSize(+event.currentTarget.value)} />
        </div>
        <div class={classes.setting}>
            Initial resources:
            <input type="number" value={initialResources()} min={1} max={100} onChange={(event) => setInitialResources(+event.currentTarget.value)} />
        </div>
        <div class={classes.buttons}>
            <button onClick={() => {
                const setupData: SetupData = {
                    size: gridSize(),
                    initialResources: initialResources()
                };
                client.createMatch(AcrossTheHex.name!, {
                    numPlayers: 2,
                    setupData,
                }).then((match) => {
                    window.location.href = `${BASE_URL}play?match=${match.matchID}`;
                });
            }}>Create multiplayer match</button>
            <button disabled>Play locally</button>
        </div>
    </div>;
}
