import { BASE_URL } from "../consts.js";
import { Buildings } from "../game.js";

export type NonRoads = Exclude<keyof typeof Buildings, "road"> | "attack";
export type TileImages = Record<NonRoads, HTMLImageElement>;

export async function loadTileImages(): Promise<TileImages> {
    const tiles = await Promise.all(
        ([...Object.keys(Buildings) as (keyof typeof Buildings)[], "attack"] as const)
            .flatMap((building): Promise<[NonRoads, HTMLImageElement]>[] => {
                if (building === "road") return [];
                return [new Promise((resolve, reject) => {
                    const svg = document.createElement("img");
                    svg.src = BASE_URL + `./tile-${building}.svg`;
                    svg.addEventListener("load", () => {
                        resolve([building, svg]);
                    });
                    svg.addEventListener("error", (err) => {
                        console.error(`Error while loading image ${svg.src}: ${err}`);
                        reject(err);
                    });
                })];
            })
    );

    return Object.fromEntries(tiles) as TileImages;
}
