import { adjacentCells } from "../game.ts";

type Neighborhood = [x: number, y: number][];

const neighborhoodCache: Neighborhood[] = [];

function offset(neighborhood: Neighborhood, cx: number, cy: number): Neighborhood {
    return neighborhood.map(([x2, y2]) => [x2 + cx, y2 + cy]);
}

export default function hexNeighborhood(cx: number, cy: number, radius: number): Neighborhood {
    if (neighborhoodCache[radius]) {
        return offset(neighborhoodCache[radius]!, cx, cy);
    } else {
        const open: [x: number, y: number, hop: number][] = [[0, 0, 0]];
        const closed: Set<string> = new Set();
        const result: Neighborhood = [];

        while (open.length > 0) {
            const [x, y, hop] = open.shift()!;
            const key = `${x}:${y}`;
            if (closed.has(key)) continue;
            closed.add(key);

            if (hop === radius) {
                result.push([x, y]);
            }

            if (hop < radius) {
                for (const [nx, ny] of adjacentCells(x, y)) {
                    open.push([nx, ny, hop + 1]);
                }
            }
        }

        neighborhoodCache[radius] = result;
        return offset(result, cx, cy);
    }
}
